@@ -5,8 +5,10 @@
 #include "dguiapplicationhelper.h"
 #include "private/dguiapplicationhelper_p.h"
 #include "dplatformhandle.h"
+
 #include <DFontManager>
 #include <DStandardPaths>
+#include <DSGApplication>
 
 #include <QHash>
 #include <QColor>
@@ -24,6 +26,7 @@
 #include <QDirIterator>
 #include <QDesktopServices>
 #include <QLibraryInfo>
+#include <QTimer>
 
 #ifdef Q_OS_UNIX
 #include <QDBusError>
@@ -33,7 +36,6 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QProcess>
-#include <DConfig>
 #endif
 #include <QDir>
 #include <QLockFile>
@@ -60,6 +62,8 @@
 #include <unistd.h>
 #endif
 
+#include "orgdeepindtkpreference.hpp"
+
 #ifdef Q_OS_UNIX
 class EnvReplaceGuard
 {
@@ -114,10 +118,9 @@ Q_GLOBAL_STATIC(DFontManager, _globalFM)
 
 #define WINDOW_THEME_KEY "_d_platform_theme"
 
-#define APP_THEME_TYPE "themeType"
-#define DTK_ENABLE_ANIMATIONS "enableDtkAnimations"
 #define DTK_ANIMATIONS_ENV "D_DTK_DISABLE_ANIMATIONS"
-Q_GLOBAL_STATIC_WITH_ARGS(DTK_CORE_NAMESPACE::DConfig, _d_dconfig, ("org.deepin.dtk.preference"));
+Q_GLOBAL_STATIC_WITH_ARGS(OrgDeepinDTKPreference, _d_dconfig, (DTK_CORE_NAMESPACE::DConfig::globalThread(), nullptr,
+                                                               "org.deepin.dtk.preference", DTK_CORE_NAMESPACE::DSGApplication::id(), {}, false, nullptr))
 
 /*!
  @private
@@ -207,11 +210,18 @@ public:
     }
     virtual bool eventFilter(QObject *watched, QEvent *event) override
     {
+        if (watched != qApp)
+            return QObject::eventFilter(watched, event);
+
         switch(event->type()) {
         case QEvent::ApplicationFontChange: {
             const QFont font(qGuiApp->font());
             m_transmitter->q_func()->fontChanged(font);
         } break;
+        case QEvent::ApplicationPaletteChange: {
+            m_transmitter->onApplicationPaletteChanged();
+            break;
+        }
         default:
             break;
         }
@@ -268,11 +278,10 @@ void DGuiApplicationHelperPrivate::initApplication(QGuiApplication *app)
     app->installEventFilter(new GuiApplicationEventFilter(this, app));
 #else
     q->connect(app, &QGuiApplication::fontChanged, q, &DGuiApplicationHelper::fontChanged);
-#endif
-    // TODO handle event in qt6.
     q->connect(app, &QGuiApplication::paletteChanged, q, [this] {
         onApplicationPaletteChanged();
     });
+#endif
 
     if (Q_UNLIKELY(!appTheme)) { // 此时说明appTheme可能已经被初始化为了systemtheme
         if (QGuiApplicationPrivate::is_app_running) {
@@ -345,10 +354,19 @@ void DGuiApplicationHelperPrivate::_q_initApplicationTheme(bool notifyChange)
     // 监听与程序主题相关的改变
     QObject::connect(appTheme, &DPlatformTheme::themeNameChanged, app, onAppThemeChanged);
     QObject::connect(appTheme, &DPlatformTheme::paletteChanged, app, onAppThemeChanged);
-    QObject::connect(appTheme, &DPlatformTheme::activeColorChanged, app, [this] {
+    QTimer *timer = new QTimer(app);
+    timer->setInterval(100);
+    timer->setSingleShot(true);
+    QObject::connect(timer, &QTimer::timeout, timer, [this] {
         if (!appPalette)
             notifyAppThemeChanged();
     });
+    QObject::connect(appTheme, &DPlatformTheme::activeColorChanged, app, [timer]{
+            timer->start();
+    });
+    QObject::connect(appTheme, &DPlatformTheme::darkActiveColorChanged, app, [timer] {
+            timer->start();
+    });
 
     // appTheme在此之前可能由systemTheme所代替被使用，此时在创建appTheme
     // 并初始化之后，应当发送信号通知程序主题的改变
@@ -361,11 +379,13 @@ void DGuiApplicationHelperPrivate::notifyAppThemeChanged()
 {
     D_Q(DGuiApplicationHelper);
     notifyAppThemeChangedByEvent();
-    // 通知主题类型发生变化, 此处可能存在误报的行为, 不过不应该对此做额外的约束
-    // 此信号的行为应当等价于 applicationPaletteChanged
-    Q_EMIT q->themeTypeChanged(q->themeType());
-    // 通知调色板对象的改变
-    Q_EMIT q->applicationPaletteChanged();
+    QMetaObject::invokeMethod(q, [q] () {
+        // 通知主题类型发生变化, 此处可能存在误报的行为, 不过不应该对此做额外的约束
+        // 此信号的行为应当等价于 applicationPaletteChanged
+        Q_EMIT q->themeTypeChanged(q->themeType());
+        // 通知调色板对象的改变
+        Q_EMIT q->applicationPaletteChanged();
+    }, Qt::QueuedConnection);
 }
 
 void DGuiApplicationHelperPrivate::notifyAppThemeChangedByEvent()
@@ -427,7 +447,7 @@ void DGuiApplicationHelperPrivate::initPaletteType() const
         return;
 
     auto applyThemeType = [this](bool emitSignal){
-        int ct = _d_dconfig->value(APP_THEME_TYPE, DGuiApplicationHelper::UnknownType).toInt();
+        int ct = _d_dconfig->themeType();
         if (ct > DGuiApplicationHelper::DarkType || ct < DGuiApplicationHelper::UnknownType)
             ct = DGuiApplicationHelper::UnknownType;
 
@@ -436,10 +456,7 @@ void DGuiApplicationHelperPrivate::initPaletteType() const
 
     applyThemeType(false);
 
-    QObject::connect(_d_dconfig, &DConfig::valueChanged, _d_dconfig, [applyThemeType](const QString &key){
-        if (key != APP_THEME_TYPE)
-            return;
-
+    QObject::connect(_d_dconfig.operator ()(), &OrgDeepinDTKPreference::themeTypeChanged, _d_dconfig, [applyThemeType] {
         applyThemeType(true);
     });
 }
@@ -750,7 +767,7 @@ static QColor dark_qpalette[QPalette::NColorRoles] {
     QColor("#282828"),                  //Base
     QColor("#252525"),                  //Window
     QColor(0, 0, 0, 0.05 * 255),        //Shadow
-    QColor("#0081ff"),                  //Highlight
+    QColor("#024CCA"),                  //Highlight
     QColor("#F1F6FF"),                  //HighlightedText
     QColor("#0082fa"),                  //Link
     QColor("#ad4579"),                  //LinkVisited
@@ -971,15 +988,7 @@ void DGuiApplicationHelper::generatePaletteColor(DPalette &base, QPalette::Color
         base.setBrush(QPalette::Disabled, role, window);
         base.setBrush(QPalette::Inactive, role, window);
         return;
-    } else if (role == QPalette::Highlight && toColorType(base) == DarkType) {
-        // 暗色模式下的高亮色亮度要降低10%，避免太突兀
-        QColor highlight = base.highlight().color();
-
-        if (highlight.isValid()) {
-            base.setColor(QPalette::Highlight, adjustColor(highlight, 0, 0, -20, 0, 0, 0, 0));
-        }
     }
-
     generatePaletteColor_helper(base, role, type);
 }
 
@@ -1032,6 +1041,20 @@ void DGuiApplicationHelper::generatePalette(DPalette &base, ColorType type)
     }
 }
 
+static inline QColor getActiveColor(const DPlatformTheme *theme, DGuiApplicationHelper::ColorType type)
+{
+    QColor activeColor;
+    if (type == DGuiApplicationHelper::DarkType) {
+        activeColor = theme->darkActiveColor();
+        if (!activeColor.isValid()) {
+            activeColor = theme->activeColor();
+        }
+    } else {
+        activeColor = theme->activeColor();
+    }
+
+    return activeColor;
+}
 /*!
   \brief 获取调色板数据.
 
@@ -1057,7 +1080,7 @@ DPalette DGuiApplicationHelper::fetchPalette(const DPlatformTheme *theme)
 
     bool ok = false;
     base_palette = theme->fetchPalette(standardPalette(type), &ok);
-    const QColor &active_color = theme->activeColor();
+    const QColor &active_color = getActiveColor(theme, type);
 
     if (active_color.isValid()) {
         base_palette.setColor(QPalette::Normal, QPalette::Highlight, active_color);
@@ -1228,7 +1251,7 @@ DPalette DGuiApplicationHelper::applicationPalette(ColorType paletteType) const
         // 覆盖DPalette中的的QPalette数据
         pa.QPalette::operator =(qGuiApp->palette());
     } else {
-        const QColor &active_color = theme->activeColor();
+        const QColor &active_color = getActiveColor(theme, type);
 
         if (active_color.isValid()) {
             // 应用Active Color
@@ -1638,7 +1661,7 @@ bool DGuiApplicationHelper::loadTranslator(const QString &fileName, const QList<
                 DPathBuf path(dir);
                 QString translatePath = (path / translateFilename).toString();
                 if (QFile::exists(translatePath + ".qm")) {
-                    qDebug() << "load translate" << translatePath;
+                    qCDebug(dgAppHelper) << "load translate" << translatePath;
                     auto translator = new QTranslator(qApp);
                     translator->load(translatePath);
                     qApp->installTranslator(translator);
@@ -1666,17 +1689,24 @@ bool DGuiApplicationHelper::loadTranslator(const QList<QLocale> &localeFallback)
 #else
     auto qTranslationsPath = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
 #endif
-    loadTranslator("qt", {qTranslationsPath}, localeFallback);
-    loadTranslator("qtbase", {qTranslationsPath}, localeFallback);
 
     DCORE_USE_NAMESPACE
-    QList<QString> translateDirs;
-    auto appName = qApp->applicationName();
     //("/home/user/.local/share", "/usr/local/share", "/usr/share")
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
+    QList<QString> qtranslateDirs = { qTranslationsPath };
     for (const auto &path : dataDirs) {
-        DPathBuf DPathBuf(path);
-        translateDirs << (DPathBuf / appName / "translations").toString();
+        DPathBuf pathBuf(path);
+        qtranslateDirs << (pathBuf / "qt" QT_STRINGIFY(QT_VERSION_MAJOR) / "translations").toString();
+    }
+
+    loadTranslator("qt", qtranslateDirs, localeFallback);
+    loadTranslator("qtbase", qtranslateDirs, localeFallback);
+
+    QList<QString> translateDirs;
+    auto appName = qApp->applicationName();
+    for (const auto &path : dataDirs) {
+        DPathBuf pathBuf(path);
+        translateDirs << (pathBuf / appName / "translations").toString();
     }
 
     // ${translateDir}/${appName}_${localeName}.qm
@@ -1741,9 +1771,8 @@ bool DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::Attribute attri
     case IsSpecialEffectsEnvironment: {
         return qgetenv("DTK_DISABLED_SPECIAL_EFFECTS").toInt() != 1;
     }
-    case IsTreelandPlatform: {
-        static bool isTreeland =  qgetenv("DDE_CURRENT_COMPOSITOR") == "TreeLand"
-            && qApp->platformName() == QByteArrayLiteral("wayland");
+    case IsWaylandPlatform: {
+        static bool isTreeland = qApp->platformName() == QByteArrayLiteral("wayland");
         return isTreeland;
     }
     case HasAnimations: {
@@ -1751,8 +1780,7 @@ bool DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::Attribute attri
         if (isDisable)
             return false;
 
-        static bool shouldEnable = _d_dconfig->value(DTK_ENABLE_ANIMATIONS, false).toBool();
-        return shouldEnable;
+        return _d_dconfig->enableDtkAnimations();
     }
     default:
         return DGuiApplicationHelperPrivate::attributes.testFlag(attribute);
@@ -1793,7 +1821,8 @@ void DGuiApplicationHelper::setPaletteType(DGuiApplicationHelper::ColorType pale
 
     d->initPaletteType();
     d->setPaletteType(paletteType, true);
-    _d_dconfig->setValue(APP_THEME_TYPE, paletteType);
+    if (!DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::DontSaveApplicationTheme))
+        _d_dconfig->setThemeType(static_cast<int>(paletteType));
 }
 
 /*!
